#
# spec file for package rxtx-java
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define src_name rxtx
%define upver 2.2
%define prever pre2
%define libversion 2
%define force_aqute_bnd 0
Name:           rxtx-java
Version:        %{upver}~%{prever}
Release:        6.1
Summary:        Full Java CommAPI implementation
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Java
URL:            http://rxtx.qbang.org/wiki/index.php/Main_Page
Source0:        http://rxtx.qbang.org/pub/rxtx/%{src_name}-%{upver}%{prever}.zip
Source1:        rxtx-osgi.bnd
Patch0:         rxtx-java-arduinouno.diff
Patch1:         rxtx-java-disable-crazy-version-tests.diff
Patch2:         rxtx-java-error.diff
Patch4:         rxtx-java-sysio.patch
Patch5:         rxtx-java-38400.patch
Patch6:         rxtx-java-version.patch
Patch7:         rxtx-java-missing-javah.patch
Patch8:         rxtx-yield.patch
BuildRequires:  automake
BuildRequires:  java-devel >= 1.8
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  zip
Requires:       librxtx%{libversion}
Obsoletes:      %{name}-src
%if 0%{?sle_version} > 150100 || 0%{?suse_version} >= 1550 || %{force_aqute_bnd}
BuildRequires:  aqute-bnd
BuildRequires:  javapackages-local
%else
BuildRequires:  javapackages-tools
%endif
%if 0%{?mdkversion}
Patch3:         rxtx-java-formatstring.patch
%endif

%description
RxTx is a Java library, using a native implementation (via JNI), providing serial
and parallel communication for the Java Development Toolkit (JDK). It is based on
the specification for Sun's Java Communications API.

%package javadoc
Summary:        Javadocs for rxtx-java
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
RxTx is a Java library, using a native implementation (via JNI), providing serial
and parallel communication for the Java Development Toolkit (JDK). It is based on
the specification for Sun's Java Communications API.

%package -n librxtx%{libversion}
Summary:        Full Java CommAPI implementation native library
Group:          Development/Libraries/C and C++
Obsoletes:      librxtx%{libversion}-devel

%description -n librxtx%{libversion}
RxTx is a Java library, using a native implementation (via JNI), providing serial
and parallel communication for the Java Development Toolkit (JDK). It is based on
the specification for Sun's Java Communications API.

%prep
%setup -q -n %{src_name}-%{upver}%{prever}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%if 0%{?mdkversion}
%patch3 -p1
%endif
%patch4
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
export THREADS_FLAG=native
rm acinclude.m4 config.guess config.sub install-sh ltmain.sh missing mkinstalldirs aclocal.m4 Makefile.in ltconfig stamp-h.in
./autogen.sh
CFLAGS="%{optflags}" LDFLAGS=-s \
%configure

%make_build

%if 0%{?sle_version} > 150100 || 0%{?suse_version} >= 1550 || %{force_aqute_bnd}
# Inject OSGi metadata
bnd wrap -p %{SOURCE1} -v %{upver} -o RXTXcomm-bnd.jar RXTXcomm.jar
mv RXTXcomm-bnd.jar RXTXcomm.jar
%endif

# build javadoc
mkdir -p javadoc
javadoc -d javadoc src/gnu/io/*.java

%install
install -dm 0755 %{buildroot}%{_jnidir} %{buildroot}%{_libdir}
make RXTX_PATH=%{buildroot}%{_libdir} JHOME=%{buildroot}%{_jnidir} install
find %{buildroot} -type f -name "*.la" -delete -print

find %{buildroot}%{_prefix} -xtype f -print | \
    sed "s@^$RPM_BUILD_ROOT@@g" > INSTALLED_FILES

if [ "$(cat INSTALLED_FILES)X" = "X" ] ; then
    echo "No files!"
    exit -1
fi

# install javadoc
install -dm 0755 %{buildroot}%{_javadocdir}
cp -r javadoc %{buildroot}%{_javadocdir}/%{name}/

%files
%doc AUTHORS ChangeLog README RMISecurityManager.html INSTALL PORTING TODO
%{_jnidir}/RXTXcomm.jar

%files javadoc
%dir %{_javadocdir}
%{_javadocdir}
%license COPYING

%files -n librxtx%{libversion}
%defattr(755,root,root)
%{_libdir}/*.so
%license COPYING

%changelog
* Wed Sep 13 2023 Fridrich Strba <fstrba@suse.com>
- Instruct bnd tools not to include non-reproducible headers in
  manifest
* Wed Jun 28 2023 Fridrich Strba <fstrba@suse.com>
- Do not build with liblock support (bsc#1212801)
* Mon Mar 13 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * rxtx-yield.patch
    + fix 'yield' becoming a restricted identifier in Java 13
- Do not force building of javadoc with source level 8
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Require java >= 1.8 for building
- Build javadoc with source level 8 to prevent problems with
  "yield' becoming a restricted identifier in Java 13
* Tue Jul 27 2021 Fridrich Strba <fstrba@suse.com>
- Define %%%%make_build for systems that don't have it defined in
  rpm macros
* Thu Mar 26 2020 Fridrich Strba <fstrba@suse.com>
- Do not distribute the sources.
- Do not distribute the headers since the shared libraries are not
  meant to be linked with, but they are dlopened from the Java
  code
- Do not distribute javadoc as a zip file but as directory in order
  to be usable directly
- Install the java jars into a platform dependent location, since
  they are having JNI calls
* Tue Mar 24 2020 Fridrich Strba <fstrba@suse.com>
- Require the aqute-bnd for build on SLE15-SP2 and higher, on
  Leap 15.2 and higher and on Factory.
- Add force_aqute_bnd define to allow building with the aqute-bnd
  requirements for repositories that backport this package to lower
  distro versions
* Fri Mar 20 2020 Fridrich Strba <fstrba@suse.com>
- Make the package version to have a tilde between the 2.2 and pre2
  so that 2.2 be an upgrade
- Allow building with java 9+ too
- Modified patch:
  * Do not call the javac twice, add the -h option to the standard
    invocation
  * Apply this patch if we are building with java 8 and higher and
    not according to distribution version
- Add osgi manifest to the jar file so that it can be used from
  eclipse
* Sat Apr 14 2018 F.Schuette@t-online.de
- make patch work for leap 15.0
* Tue Feb 27 2018 F.Schuette@t-online.de
- javah is missing from java-9, patch to use javac -h instead
* Sun Oct  1 2017 F.Schuette@t-online.de
- change source, target to 1.6
* Sun Oct  1 2017 F.Schuette@t-online.de
- BuildRequires java-devel <= 1.8.0
* Tue May  5 2015 F.Schuette@t-online.de
- changed 38400 patch like dstoecker suggested
* Sat May  2 2015 F.Schuette@t-online.de
- remove rules file, user has to be in dialout and lock
* Fri May  1 2015 F.Schuette@t-online.de
- fix serial baudrate 38400 not possible
- fix version # 2.2.pre2
- split package
* Fri May 31 2013 dvaleev@suse.com
- Detect if sysio available (rxtx-java-sysio.patch)
* Fri Dec 30 2011 seife+obs@b1-systems.com
- buildrequire automake and libtool to fix Factory build
* Sat Sep 24 2011 seife+obs@b1-systems.com
- fix build for SLES10, remove always false %%if clause
* Sat Sep 17 2011 seife+obs@b1-systems.com
- also fix build on SLES11SP1
* Sat Sep 17 2011 seife+obs@b1-systems.com
- fix build on openSUSE 11.3  (no pkgconfig() stuff)
* Sat Sep 17 2011 seife+obs@b1-systems.com
- use liblockdev to lock devices
- report locking problems with hint on possible problem
- fix build on newer kernels (no UTS_RELEASE)
* Fri Aug 26 2011 seife+obs@b1-systems.com
- add ttyACM ports so that it works with arduino uno
* Sun Aug 22 2010 kkaempf@novell.com
- update to 2.2pre2
* Sun Mar 11 2007 developer@jefferyfernandez.id.au
- Initial Release for openSUSE
